@@ -1,9 +1,3 @@
-from __future__ import print_function
-from __future__ import unicode_literals
-from __future__ import division
-from __future__ import absolute_import
-from future import standard_library
-standard_library.install_aliases()
 import numpy as np
 import dbdreader
 
@@ -27,9 +21,9 @@ print("\nmax depth %f m"%(max_depth))
 lat,lon=dbd.get_xy("m_lat","m_lon")
 
 # interpolate roll speed on depth time
-tm,depth,roll,speed=dbd.get_sync("m_depth",["m_roll","m_speed"])
+tm,depth,roll,speed=dbd.get_sync("m_depth","m_roll","m_speed")
 
-print("\nmax speed %f m/s"%(speed.max()))
+print("\nmax speed %f m/s"%(np.nanmax(speed)))
 
 # close the file again.
 dbd.close()
